Crate bloom_html

source ·

Modules

  • Make sure to import bloom_html::prelude::* wherever you want to use (https://crates.io/crates/bloom-rsx)[bloom-rsx] to render HtmlNodes
  • Some basic html tags

Structs

  • Represents a reference to a DOM element. Obtain this via
  • Represents an html tag such as <div>, <span>, etc.

Enums

  • The Node-type to use bloom in Browser-Environments. A HtmlNode is equivalent to a browser DOM-node. It can represent an HTML Element (
    , , etc.), a text-node or a comment.

Functions

  • shortcut for generating text-nodes

Type Aliases

  • Event handlers are basically just closures that take a web_sys::Event as an argument. This type only provides a convenience for implementing the actual render-functions.