Type Alias bloom_html::EventHandler

source ·
pub type EventHandler = Box<dyn Fn(Event) + Send + Sync + 'static>;
Event handlers are basically just closures that take a web_sys::Event as an argument. This type only provides a convenience for implementing the actual render-functions.

Aliased Type

struct EventHandler(/* private fields */);